@@ -6,8 +6,10 @@ import (
 
 //go:generate protoc -I ../../.. --go_opt=plugins=grpc --go_out=../../.. waypoint/builtin/docker/plugin.proto
 
+const platformName = "docker"
+
 // Options are the SDK options to use for instantiation.
 var Options = []sdk.Option{
-	sdk.WithComponents(&Builder{}, &Registry{}, &Platform{}),
+	sdk.WithComponents(&Builder{}, &Registry{}, &Platform{}, &TaskLauncher{}),
 	// sdk.WithMappers(PackImageMapper),
 }
