@@ -291,6 +291,12 @@ func Commands(
 			}, nil
 		},
 
+		"release list": func() (cli.Command, error) {
+			return &ReleaseListCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+
 		"server": func() (cli.Command, error) {
 			return &helpCommand{
 				SynopsisText: helpText["server"][0],
@@ -486,6 +492,11 @@ func Commands(
 				baseCommand: baseCommand,
 			}, nil
 		},
+		"project inspect": func() (cli.Command, error) {
+			return &ProjectInspectCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
 
 		"fmt": func() (cli.Command, error) {
 			return &FmtCommand{
@@ -769,9 +780,9 @@ Waypoint will search for artifacts to pass to the deployment phase.
 	},
 
 	"auth-method": {
-		"Auth Method Management",
+		"Auth method management",
 		`
-Auth Method Management
+Auth method management
 
 The auth-method commands can be used to manage how users can authenticate
 into the Waypoint server. For day-to-day Waypoint users, you likely want
