@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"os"
+	"sort"
 	"strings"
 	"time"
 
@@ -415,7 +416,17 @@ func (c *ServerUpgradeCommand) Flags() *flag.Sets {
 			Usage:   "Enable or disable taking a snapshot of Waypoint server prior to upgrades.",
 		})
 
-		for name, platform := range serverinstall.Platforms {
+		// Add platforms in alphabetical order. A consistent order is important for repeatable doc generation.
+		i := 0
+		sortedPlatformNames := make([]string, len(serverinstall.Platforms))
+		for name := range serverinstall.Platforms {
+			sortedPlatformNames[i] = name
+			i++
+		}
+		sort.Strings(sortedPlatformNames)
+
+		for _, name := range sortedPlatformNames {
+			platform := serverinstall.Platforms[name]
 			platformSet := set.NewSet(name + " Options")
 			platform.UpgradeFlags(platformSet)
 		}
