@@ -1,12 +1,11 @@
 package cli
 
 import (
+	"context"
 	"encoding/json"
 	"fmt"
 	"strings"
 
-	"github.com/hashicorp/waypoint/internal/version"
-
 	"github.com/dustin/go-humanize"
 	"github.com/golang/protobuf/ptypes"
 	"github.com/golang/protobuf/ptypes/empty"
@@ -16,19 +15,21 @@ import (
 
 	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
 	"github.com/hashicorp/waypoint/internal/clicontext"
+	clientpkg "github.com/hashicorp/waypoint/internal/client"
 	"github.com/hashicorp/waypoint/internal/clierrors"
 	"github.com/hashicorp/waypoint/internal/pkg/flag"
 	pb "github.com/hashicorp/waypoint/internal/server/gen"
+	"github.com/hashicorp/waypoint/internal/version"
 )
 
 type StatusCommand struct {
 	*baseCommand
 
-	flagContextName string
-	flagVerbose     bool
-	flagJson        bool
-	flagAllProjects bool
-	filterFlags     filterFlags
+	flagContextName      string
+	flagVerbose          bool
+	flagJson             bool
+	flagAllProjects      bool
+	flagRefreshAppStatus bool
 
 	serverCtx *clicontext.Config
 }
@@ -39,7 +40,7 @@ func (c *StatusCommand) Run(args []string) int {
 	if err := c.Init(
 		WithArgs(args),
 		WithFlags(flagSet),
-		WithConfig(true), // optional config loading
+		WithOptionalApp(), // optional config loading, no hard requirement on an app target
 	); err != nil {
 		return 1
 	}
@@ -101,6 +102,15 @@ func (c *StatusCommand) Run(args []string) int {
 		c.ui.Output(wpAppFlagAndTargetIncludedMsg, terminal.WithWarningStyle())
 	}
 
+	// Optionally refresh status
+	if c.flagRefreshAppStatus {
+		if err := c.RefreshApplicationStatus(projectTarget, appTarget); err != nil {
+			c.ui.Output("CLI failed to refresh project statuses: "+clierrors.Humanize(err), terminal.WithErrorStyle())
+			return 1
+		}
+		c.ui.Output("")
+	}
+
 	// Generate a status view
 	if projectTarget == "" || c.flagAllProjects {
 		// Show high-level status of all projects
@@ -146,6 +156,246 @@ func (c *StatusCommand) Run(args []string) int {
 	return 0
 }
 
+// RefreshApplicationStatus takes a project and application target and generates
+// a list of applications to refresh the status on. If all projects are requested
+// to be refreshed, the CLI will do its best to honor the request. However if
+// a project is local and the CLI was not invoked inside that project dir, the
+// CLI won't be able to refresh that project's application statuses.
+func (c *StatusCommand) RefreshApplicationStatus(projectTarget, appTarget string) error {
+	// Get our API client
+	client := c.project.Client()
+
+	// Get the entire list of apps
+	// Determine project locality
+	// Do the Work (local or remote)
+	if c.flagAllProjects {
+		c.ui.Output("This command does not support refreshing statuses for all "+
+			"defined projects in Waypoint. Use the project argument to narrow down "+
+			"which projects you hope to refresh a status on.", terminal.WithWarningStyle())
+		return nil
+	}
+
+	projectResp, err := client.GetProject(c.Ctx, &pb.GetProjectRequest{
+		Project: &pb.Ref_Project{
+			Project: projectTarget,
+		},
+	})
+	if err != nil {
+		if status.Code(err) == codes.NotFound {
+			var serverAddress string
+			if c.serverCtx != nil {
+				serverAddress = c.serverCtx.Server.Address
+			}
+
+			c.ui.Output(wpProjectNotFound, projectTarget, serverAddress, terminal.WithErrorStyle())
+		}
+		return err
+	}
+	project := projectResp.Project
+
+	workspace, err := c.getWorkspaceFromProject(projectResp)
+	if err != nil {
+		return err
+	}
+
+	if appTarget != "" {
+		// Single app refresh
+		var app *pb.Application
+		for _, a := range project.Applications {
+			if a.Name == appTarget {
+				app = a
+				break
+			}
+		}
+		if app == nil {
+			return fmt.Errorf("Did not find application %q in project %q", appTarget, projectTarget)
+		}
+
+		appList := []*pb.Application{app}
+
+		if err = c.doRefresh(project, appList, workspace); err != nil {
+			c.ui.Output("Failed to refresh app %q status in project %q: %s",
+				app.Name,
+				project.Name,
+				clierrors.Humanize(err), terminal.WithErrorStyle())
+			return err
+		}
+	} else {
+		if err = c.doRefresh(project, project.Applications, workspace); err != nil {
+			c.ui.Output("Failed to refresh app statuses in project %q: %s",
+				project.Name,
+				clierrors.Humanize(err), terminal.WithErrorStyle())
+			return err
+		}
+	}
+
+	return nil
+}
+
+// doRefresh takes a list of applications and their parent project and will
+// attempt to run the statusfunc configured for each requested application.
+func (c *StatusCommand) doRefresh(
+	project *pb.Project,
+	appList []*pb.Application,
+	workspace string,
+) error {
+	sg := c.ui.StepGroup()
+	defer sg.Wait()
+
+	s := sg.Add("")
+	c.ui.Output("")
+	for _, app := range appList {
+		s.Update("Refreshing status for app %q in project %q. Refreshing could take a while...",
+			app.Name, project.Name)
+
+		err := c.refreshAppStatus(project, app, workspace)
+		if err != nil {
+			s.Update("Failed to refresh app status\n")
+			s.Status(terminal.StatusError)
+			s.Done()
+
+			c.ui.Output(
+				"Error attempting to refresh application %q: %s",
+				app.Name,
+				clierrors.Humanize(err),
+				terminal.WithErrorStyle(),
+			)
+			return err
+		}
+	}
+
+	s.Update("Finished refreshing app statuses in project %q", project.Name)
+	s.Done()
+	c.ui.Output("")
+
+	return nil
+}
+
+// refreshAppStatus takes a project and a single application and uses
+// the local runner to execute a StatusReport refresh function by getting
+// the latest Deployment or Release and using the application client to
+// refresh the apps Status Report.
+func (c *StatusCommand) refreshAppStatus(
+	project *pb.Project,
+	app *pb.Application,
+	workspace string,
+) error {
+	if c.refApp == nil {
+		// We must setup app ref so DoApp has the context for which app to execute
+		// its operations on. WithOptionalApp does not setup this ref for us.
+		c.refApp = &pb.Ref_Application{
+			Application: app.Name,
+			Project:     project.Name,
+		}
+	}
+	err := c.DoApp(c.Ctx, func(ctx context.Context, appClient *clientpkg.App) error {
+		// Get our API client
+		client := c.project.Client()
+
+		// Get Latest Deployment and Release
+
+		// Deployments
+		deploymentsResp, err := client.UI_ListDeployments(c.Ctx, &pb.UI_ListDeploymentsRequest{
+			Application: &pb.Ref_Application{
+				Application: app.Name,
+				Project:     project.Name,
+			},
+			Workspace: &pb.Ref_Workspace{
+				Workspace: workspace,
+			},
+			Order: &pb.OperationOrder{
+				Order: pb.OperationOrder_COMPLETE_TIME,
+				Limit: 1,
+			},
+		})
+		if err != nil {
+			if s, ok := status.FromError(err); ok {
+				if s.Code() == codes.Unimplemented {
+					return c.errAPIUnimplemented(err)
+				}
+			}
+			return err
+		}
+
+		var deployment *pb.Deployment
+		if deploymentsResp.Deployments != nil && len(deploymentsResp.Deployments) > 0 {
+			deployment = deploymentsResp.Deployments[0].Deployment
+		} else {
+			c.ui.Output("No deployments in project %q for app %q to refresh a status on!",
+				project.Name,
+				app.Name,
+				terminal.WithWarningStyle())
+			// We probably don't have a release either, so return early
+			return nil
+		}
+
+		_, err = appClient.StatusReport(c.Ctx, &pb.Job_StatusReportOp{
+			Target: &pb.Job_StatusReportOp_Deployment{
+				Deployment: deployment,
+			},
+		})
+		if err != nil {
+			c.ui.Output(clierrors.Humanize(err), terminal.WithErrorStyle())
+			return err
+		}
+
+		// Releases
+		releaseResp, err := client.UI_ListReleases(c.Ctx, &pb.UI_ListReleasesRequest{
+			Application: &pb.Ref_Application{
+				Application: app.Name,
+				Project:     project.Name,
+			},
+			Workspace: &pb.Ref_Workspace{
+				Workspace: workspace,
+			},
+			Order: &pb.OperationOrder{
+				Order: pb.OperationOrder_COMPLETE_TIME,
+				Limit: 1,
+			},
+		})
+		if err != nil {
+			if s, ok := status.FromError(err); ok {
+				if s.Code() == codes.Unimplemented {
+					return c.errAPIUnimplemented(err)
+				}
+			}
+			return err
+		}
+
+		var release *pb.Release
+		if releaseResp.Releases != nil && len(releaseResp.Releases) > 0 {
+			release = releaseResp.Releases[0].Release
+		}
+
+		if release != nil && !release.Unimplemented {
+			_, err = appClient.StatusReport(c.Ctx, &pb.Job_StatusReportOp{
+				Target: &pb.Job_StatusReportOp_Release{
+					Release: release,
+				},
+			})
+			if err != nil {
+				c.ui.Output(clierrors.Humanize(err), terminal.WithErrorStyle())
+				return err
+			}
+		}
+
+		return nil
+	})
+	if err != nil {
+		if err != ErrSentinel {
+			c.ui.Output(clierrors.Humanize(err), terminal.WithErrorStyle())
+		}
+
+		return err
+	}
+
+	return nil
+}
+
+//
+// UI format functions
+//
+
 // FormatProjectAppStatus formats all applications inside a project
 func (c *StatusCommand) FormatProjectAppStatus(projectTarget string) error {
 	if !c.flagJson && c.serverCtx != nil {
@@ -198,27 +448,12 @@ func (c *StatusCommand) FormatProjectAppStatus(projectTarget string) error {
 		if err != nil {
 			if s, ok := status.FromError(err); ok {
 				if s.Code() == codes.Unimplemented {
-					var serverVersion string
-					serverVersionResp := c.project.ServerVersion()
-					if serverVersionResp != nil {
-						serverVersion = serverVersionResp.Version
-					}
-
-					var clientVersion string
-					clientVersionResp := version.GetVersion()
-					if clientVersionResp != nil {
-						clientVersion = clientVersionResp.Version
-					}
-
-					c.project.UI.Output(
-						fmt.Sprintf("This CLI version %q is incompatible with the current server %q - missing UI_ListDeployments method. Upgrade your server to v0.5.0 or higher or downgrade your CLI to v0.4 or older.", clientVersion, serverVersion),
-						terminal.WithErrorStyle(),
-					)
-					return ErrSentinel
+					return c.errAPIUnimplemented(err)
 				}
 			}
 			return err
 		}
+
 		var appDeployStatus *pb.StatusReport
 		if deploymentsResp.Deployments != nil && len(deploymentsResp.Deployments) > 0 {
 			appDeployStatus = deploymentsResp.Deployments[0].LatestStatusReport
@@ -251,6 +486,11 @@ func (c *StatusCommand) FormatProjectAppStatus(projectTarget string) error {
 			},
 		})
 		if err != nil {
+			if s, ok := status.FromError(err); ok {
+				if s.Code() == codes.Unimplemented {
+					return c.errAPIUnimplemented(err)
+				}
+			}
 			return err
 		}
 		var appReleaseStatus *pb.StatusReport
@@ -363,23 +603,7 @@ func (c *StatusCommand) FormatAppStatus(projectTarget string, appTarget string)
 	if err != nil {
 		if s, ok := status.FromError(err); ok {
 			if s.Code() == codes.Unimplemented {
-				var serverVersion string
-				serverVersionResp := c.project.ServerVersion()
-				if serverVersionResp != nil {
-					serverVersion = serverVersionResp.Version
-				}
-
-				var clientVersion string
-				clientVersionResp := version.GetVersion()
-				if clientVersionResp != nil {
-					clientVersion = clientVersionResp.Version
-				}
-
-				c.project.UI.Output(
-					fmt.Sprintf("This CLI version %q is incompatible with the current server %q - missing UI_ListDeployments method. Upgrade your server to v0.5.0 or higher or downgrade your CLI to v0.4 or older.", clientVersion, serverVersion),
-					terminal.WithErrorStyle(),
-				)
-				return ErrSentinel
+				return c.errAPIUnimplemented(err)
 			}
 		}
 		return err
@@ -496,6 +720,11 @@ func (c *StatusCommand) FormatAppStatus(projectTarget string, appTarget string)
 		},
 	})
 	if err != nil {
+		if s, ok := status.FromError(err); ok {
+			if s.Code() == codes.Unimplemented {
+				return c.errAPIUnimplemented(err)
+			}
+		}
 		return err
 	}
 
@@ -707,23 +936,7 @@ func (c *StatusCommand) FormatProjectStatus() error {
 			if err != nil {
 				if s, ok := status.FromError(err); ok {
 					if s.Code() == codes.Unimplemented {
-						var serverVersion string
-						serverVersionResp := c.project.ServerVersion()
-						if serverVersionResp != nil {
-							serverVersion = serverVersionResp.Version
-						}
-
-						var clientVersion string
-						clientVersionResp := version.GetVersion()
-						if clientVersionResp != nil {
-							clientVersion = clientVersionResp.Version
-						}
-
-						c.project.UI.Output(
-							fmt.Sprintf("This CLI version %q is incompatible with the current server %q - missing UI_ListDeployments method. Upgrade your server to v0.5.0 or higher or downgrade your CLI to v0.4 or older.", clientVersion, serverVersion),
-							terminal.WithErrorStyle(),
-						)
-						return ErrSentinel
+						return c.errAPIUnimplemented(err)
 					}
 				}
 				return err
@@ -753,6 +966,11 @@ func (c *StatusCommand) FormatProjectStatus() error {
 				},
 			})
 			if err != nil {
+				if s, ok := status.FromError(err); ok {
+					if s.Code() == codes.Unimplemented {
+						return c.errAPIUnimplemented(err)
+					}
+				}
 				return err
 			}
 
@@ -923,7 +1141,9 @@ func (c *StatusCommand) outputJsonAppStatus(
 	return nil
 }
 
-// Status Helpers
+//
+// CLI Status Helpers
+//
 
 func (c *StatusCommand) FormatStatusReportComplete(
 	statusReport *pb.StatusReport,
@@ -1036,6 +1256,28 @@ func (c *StatusCommand) formatJsonMap(t *terminal.Table) []map[string]interface{
 	return result
 }
 
+func (c *StatusCommand) errAPIUnimplemented(err error) error {
+	var serverVersion string
+	serverVersionResp := c.project.ServerVersion()
+	if serverVersionResp != nil {
+		serverVersion = serverVersionResp.Version
+	}
+
+	var clientVersion string
+	clientVersionResp := version.GetVersion()
+	if clientVersionResp != nil {
+		clientVersion = clientVersionResp.Version
+	}
+
+	c.project.UI.Output("This CLI version %q is incompatible with the current "+
+		"server %q - missing API method. Upgrade your server to v0.5.0 or higher: %s",
+		clierrors.Humanize(err),
+		clientVersion, serverVersion,
+		terminal.WithErrorStyle(),
+	)
+	return err
+}
+
 func (c *StatusCommand) Flags() *flag.Sets {
 	return c.flagSet(0, func(set *flag.Sets) {
 		f := set.NewSet("Command Options")
@@ -1058,6 +1300,12 @@ func (c *StatusCommand) Flags() *flag.Sets {
 			Target: &c.flagAllProjects,
 			Usage:  "Output status about every project in a workspace.",
 		})
+
+		f.BoolVar(&flag.BoolVar{
+			Name:   "refresh",
+			Target: &c.flagRefreshAppStatus,
+			Usage:  "Refresh application status for the requested app or apps in a project.",
+		})
 	})
 }
 
@@ -1070,14 +1318,19 @@ func (c *StatusCommand) AutocompleteFlags() complete.Flags {
 }
 
 func (c *StatusCommand) Synopsis() string {
-	return "List statuses."
+	return "List and refresh application statuses."
 }
 
 func (c *StatusCommand) Help() string {
 	return formatHelp(`
 Usage: waypoint status [options] [project]
 
-  View the current status of projects and applications managed by Waypoint.
+  View the current status of projects, applications, and their resources
+  managed by Waypoint.
+
+  When the '-refresh' flag is included, this command will attempt to regenerate
+  every requested application's status report on-demand for both local and remote
+  data sourced projects.
 
 ` + c.Flags().Help())
 }
