@@ -25,6 +25,7 @@ type Project struct {
 	workspace           *pb.Ref_Workspace
 	runner              *pb.Ref_Runner
 	labels              map[string]string
+	variables           []*pb.Variable
 	dataSourceOverrides map[string]string
 	cleanupFunc         func()
 	serverVersion       *pb.VersionInfo
@@ -227,6 +228,14 @@ func WithClientConnect(opts ...serverclient.ConnectOption) Option {
 	}
 }
 
+// WithVariables sets variable values from flags and local env on any operations.
+func WithVariables(m []*pb.Variable) Option {
+	return func(c *Project, cfg *config) error {
+		c.variables = m
+		return nil
+	}
+}
+
 // WithLabels sets the labels or any operations.
 func WithLabels(m map[string]string) Option {
 	return func(c *Project, cfg *config) error {
