@@ -22,6 +22,7 @@ import (
 	"github.com/hashicorp/waypoint-plugin-sdk/datadir"
 	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
 	configpkg "github.com/hashicorp/waypoint/internal/config"
+	"github.com/hashicorp/waypoint/internal/config/variables"
 	"github.com/hashicorp/waypoint/internal/core"
 	"github.com/hashicorp/waypoint/internal/factory"
 	"github.com/hashicorp/waypoint/internal/plugin"
@@ -37,30 +38,29 @@ func (r *Runner) executeJob(
 	job *pb.Job,
 	wd string,
 ) (*pb.Job_Result, error) {
+	// NOTE(mitchellh; krantzinator): For now, we query the project directly here
+	// since we use it only in case of a missing local waypoint.hcl, and to
+	// collect input variable values set on the server. I can see us moving this
+	// to accept() eventually though if other data is used.
+	resp, err := r.client.GetProject(ctx, &pb.GetProjectRequest{
+		Project: &pb.Ref_Project{
+			Project: job.Application.Project,
+		},
+	})
+	if err != nil {
+		return nil, err
+	}
+
 	// Eventually we'll need to extract the data source. For now we're
 	// just building for local exec so it is the working directory.
 	path, err := configpkg.FindPath(wd, "", false)
 	if err != nil {
 		return nil, err
 	}
-
 	if path == "" {
 		// If no waypoint.hcl file is found in the downloaded data, look for
 		// a default waypoint HCL.
-		//
-		// NOTE(mitchellh): For now, we query the project directly here
-		// since we don't need it for anything else. I can see us moving this
-		// to accept() eventually though if other data is used.
 		log.Trace("waypoint.hcl not found in downloaded data, looking for default in server")
-		resp, err := r.client.GetProject(ctx, &pb.GetProjectRequest{
-			Project: &pb.Ref_Project{
-				Project: job.Application.Project,
-			},
-		})
-		if err != nil {
-			return nil, err
-		}
-
 		if v := resp.Project.WaypointHcl; len(v) > 0 {
 			log.Info("using waypoint.hcl associated with the project in the server")
 
@@ -124,6 +124,25 @@ func (r *Runner) executeJob(
 		return nil, err
 	}
 
+	// Here we'll load our values from auto vars files and the server/UI, and
+	// combine them with any values set on the job
+	// The order values are added to our final pbVars slice is the order
+	// of precedence
+	vcsVars, diags := variables.LoadAutoFiles(wd)
+	if diags.HasErrors() {
+		return nil, diags
+	}
+
+	pbVars := resp.Project.GetVariables()
+	pbVars = append(pbVars, vcsVars...)
+	pbVars = append(pbVars, job.Variables...)
+
+	// evaluate all variables against the variable blocks we just decoded
+	inputVars, diags := variables.EvaluateVariables(pbVars, cfg.InputVariables, log)
+	if diags.HasErrors() {
+		return nil, diags
+	}
+
 	// Build our job info
 	jobInfo := &component.JobInfo{
 		Id:    job.Id,
@@ -140,6 +159,7 @@ func (r *Runner) executeJob(
 		core.WithConfig(cfg),
 		core.WithDataDir(projDir),
 		core.WithLabels(job.Labels),
+		core.WithVariables(inputVars),
 		core.WithWorkspace(job.Workspace.Workspace),
 		core.WithJobInfo(jobInfo),
 	)
@@ -206,7 +226,7 @@ func (r *Runner) executeJob(
 		return r.executeQueueProjectOp(ctx, log, job, project)
 
 	case *pb.Job_StatusReport:
-		return r.executeStatusReportOp(ctx, job, project)
+		return r.executeStatusReportOp(ctx, log, job, project)
 
 	default:
 		return nil, status.Errorf(codes.Aborted, "unknown operation %T", job.Operation)
@@ -259,7 +279,10 @@ func (r *Runner) pluginFactories(
 		}
 
 		// Find our plugin.
-		cmd, err := plugin.Discover(pluginCfg, pluginPaths)
+		cmd, err := plugin.Discover(&plugin.Config{
+			Name:     pluginCfg.Name,
+			Checksum: pluginCfg.Checksum,
+		}, pluginPaths)
 		if err != nil {
 			plog.Warn("error searching for plugin", "err", err)
 			perr = multierror.Append(perr, err)
@@ -277,6 +300,7 @@ func (r *Runner) pluginFactories(
 			} else {
 				plog.Debug("plugin found as builtin")
 				for _, t := range pluginCfg.Types() {
+					plog.Info("register", "type", t.String(), "nil", result[t] == nil)
 					result[t].Register(pluginCfg.Name, plugin.BuiltinFactory(pluginCfg.Name, t))
 				}
 			}
