@@ -1,5 +1,5 @@
 import { module, test } from 'qunit';
-import { visit } from '@ember/test-helpers';
+import { visit, currentURL } from '@ember/test-helpers';
 import { setupApplicationTest } from 'ember-qunit';
 import { setupMirage } from 'ember-cli-mirage/test-support';
 import login from 'waypoint/tests/helpers/login';
@@ -15,7 +15,7 @@ module('Acceptance | deployment detail', function (hooks) {
     let deployment = this.server.create('deployment', 'random', { application });
     this.server.create('status-report', 'ready', { application, target: deployment });
 
-    await visit(`/default/acme-project/app/acme-app/deployment/${deployment.id}`);
+    await visit(`/default/acme-project/app/acme-app/deployment/seq/${deployment.sequence}`);
 
     assert.dom('[data-test-status-report-indicator="ready"]').exists();
   });
@@ -25,8 +25,18 @@ module('Acceptance | deployment detail', function (hooks) {
     let application = this.server.create('application', { name: 'acme-app', project });
     let deployment = this.server.create('deployment', 'random', { application });
 
-    await visit(`/default/acme-project/app/acme-app/deployment/${deployment.id}`);
+    await visit(`/default/acme-project/app/acme-app/deployment/seq/${deployment.sequence}`);
 
     assert.dom('[data-test-status-report-indicator]').doesNotExist();
   });
+
+  test('redirects from the ID to the sequence route', async function (assert) {
+    let project = this.server.create('project', { name: 'acme-project' });
+    let application = this.server.create('application', { name: 'acme-app', project });
+    let deployment = this.server.create('deployment', 'random', { application });
+
+    await visit(`/default/acme-project/app/acme-app/deployment/${deployment.id}`);
+
+    assert.equal(currentURL(), `/default/acme-project/app/acme-app/deployment/seq/${deployment.sequence}`);
+  });
 });
