@@ -2,12 +2,11 @@ export const ALERT_BANNER_ACTIVE = true
 
 // https://github.com/hashicorp/web-components/tree/master/packages/alert-banner
 export default {
-  tag: 'June 8-11',
-  url: 'https://hashiconf.com/europe/?utm_source=DocsBanner',
-  text:
-    'The countdown to HashiConf Europe is on, and the full schedule is now live.',
-  linkText: 'View Schedule',
+  tag: 'Thank you',
+  url: 'https://hashiconf.com/europe',
+  text: 'HashiConf Europe is a wrap. Watch this year’s sessions on-demand.',
+  linkText: 'Watch Now',
   // Set the `expirationDate prop with a datetime string (e.g. `2020-01-31T12:00:00-07:00`)
   // if you'd like the component to stop showing at or after a certain date
-  expirationDate: null,
+  expirationDate: `2021-06-20T12:00:00-07:00`,
 }
